==> zio-aws-swf_3-5.17.104.5-sources.jar: zio/aws/swf/model/LambdaFunctionFailedEventAttributes.scala <==
package zio.aws.swf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.swf.model.primitives.{Data, FailureReason, EventId}
import scala.jdk.CollectionConverters.*
final case class LambdaFunctionFailedEventAttributes(
    scheduledEventId: EventId,
    startedEventId: EventId,
    reason: Option[FailureReason] = None,
    details: Option[Data] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.swf.model.LambdaFunctionFailedEventAttributes = {
    import LambdaFunctionFailedEventAttributes.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.swf.model.LambdaFunctionFailedEventAttributes
      .builder()
      .scheduledEventId(EventId.unwrap(scheduledEventId): java.lang.Long)
      .startedEventId(EventId.unwrap(startedEventId): java.lang.Long)
      .optionallyWith(
        reason.map(value => FailureReason.unwrap(value): java.lang.String)
      )(_.reason)
      .optionallyWith(
        details.map(value => Data.unwrap(value): java.lang.String)
      )(_.details)
      .build()
  }
  def asReadOnly
      : zio.aws.swf.model.LambdaFunctionFailedEventAttributes.ReadOnly =
    zio.aws.swf.model.LambdaFunctionFailedEventAttributes.wrap(buildAwsValue())
}
object LambdaFunctionFailedEventAttributes {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.swf.model.LambdaFunctionFailedEventAttributes
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.swf.model.LambdaFunctionFailedEventAttributes =
      zio.aws.swf.model.LambdaFunctionFailedEventAttributes(
        scheduledEventId,
        startedEventId,
        reason.map(value => value),
        details.map(value => value)
      )
    def scheduledEventId: EventId
    def startedEventId: EventId
    def reason: Option[FailureReason]
    def details: Option[Data]
    def getScheduledEventId: ZIO[Any, Nothing, EventId] =
      ZIO.succeed(scheduledEventId)
    def getStartedEventId: ZIO[Any, Nothing, EventId] =
      ZIO.succeed(startedEventId)
    def getReason: ZIO[Any, AwsError, FailureReason] =
      AwsError.unwrapOptionField("reason", reason)
    def getDetails: ZIO[Any, AwsError, Data] =
      AwsError.unwrapOptionField("details", details)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.swf.model.LambdaFunctionFailedEventAttributes
  ) extends zio.aws.swf.model.LambdaFunctionFailedEventAttributes.ReadOnly {
    override val scheduledEventId: EventId =
      zio.aws.swf.model.primitives.EventId(impl.scheduledEventId())
    override val startedEventId: EventId =
      zio.aws.swf.model.primitives.EventId(impl.startedEventId())
    override val reason: Option[FailureReason] = scala
      .Option(impl.reason())
      .map(value => zio.aws.swf.model.primitives.FailureReason(value))
    override val details: Option[Data] = scala
      .Option(impl.details())
      .map(value => zio.aws.swf.model.primitives.Data(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.swf.model.LambdaFunctionFailedEventAttributes
  ): zio.aws.swf.model.LambdaFunctionFailedEventAttributes.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-swf_3-5.17.239.1-sources.jar: zio/aws/swf/model/LambdaFunctionFailedEventAttributes.scala <==
package zio.aws.swf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.swf.model.primitives.{Data, FailureReason, EventId}
import scala.jdk.CollectionConverters.*
final case class LambdaFunctionFailedEventAttributes(
    scheduledEventId: EventId,
    startedEventId: EventId,
    reason: Optional[FailureReason] = Optional.Absent,
    details: Optional[Data] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.swf.model.LambdaFunctionFailedEventAttributes = {
    import LambdaFunctionFailedEventAttributes.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.swf.model.LambdaFunctionFailedEventAttributes
      .builder()
      .scheduledEventId(EventId.unwrap(scheduledEventId): java.lang.Long)
      .startedEventId(EventId.unwrap(startedEventId): java.lang.Long)
      .optionallyWith(
        reason.map(value => FailureReason.unwrap(value): java.lang.String)
      )(_.reason)
      .optionallyWith(
        details.map(value => Data.unwrap(value): java.lang.String)
      )(_.details)
      .build()
  }
  def asReadOnly
      : zio.aws.swf.model.LambdaFunctionFailedEventAttributes.ReadOnly =
    zio.aws.swf.model.LambdaFunctionFailedEventAttributes.wrap(buildAwsValue())
}
object LambdaFunctionFailedEventAttributes {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.swf.model.LambdaFunctionFailedEventAttributes
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.swf.model.LambdaFunctionFailedEventAttributes =
      zio.aws.swf.model.LambdaFunctionFailedEventAttributes(
        scheduledEventId,
        startedEventId,
        reason.map(value => value),
        details.map(value => value)
      )
    def scheduledEventId: EventId
    def startedEventId: EventId
    def reason: Optional[FailureReason]
    def details: Optional[Data]
    def getScheduledEventId: ZIO[Any, Nothing, EventId] =
      ZIO.succeed(scheduledEventId)
    def getStartedEventId: ZIO[Any, Nothing, EventId] =
      ZIO.succeed(startedEventId)
    def getReason: ZIO[Any, AwsError, FailureReason] =
      AwsError.unwrapOptionField("reason", reason)
    def getDetails: ZIO[Any, AwsError, Data] =
      AwsError.unwrapOptionField("details", details)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.swf.model.LambdaFunctionFailedEventAttributes
  ) extends zio.aws.swf.model.LambdaFunctionFailedEventAttributes.ReadOnly {
    override val scheduledEventId: EventId =
      zio.aws.swf.model.primitives.EventId(impl.scheduledEventId())
    override val startedEventId: EventId =
      zio.aws.swf.model.primitives.EventId(impl.startedEventId())
    override val reason: Optional[FailureReason] = zio.aws.core.internal
      .optionalFromNullable(impl.reason())
      .map(value => zio.aws.swf.model.primitives.FailureReason(value))
    override val details: Optional[Data] = zio.aws.core.internal
      .optionalFromNullable(impl.details())
      .map(value => zio.aws.swf.model.primitives.Data(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.swf.model.LambdaFunctionFailedEventAttributes
  ): zio.aws.swf.model.LambdaFunctionFailedEventAttributes.ReadOnly =
    new Wrapper(impl)
}
